Marine cold spells (MCSs) are categorized as moderate when the sea-surface temperature (SST) is below the 10th percentile of the climatological distribution for five days or longer; the subsequent categories are defined with respect to the difference between the SST and the climatological distribution average: strong, severe or extreme, if that difference is, respectively, more than two, three or four times the difference between the 10th percentile and the climatological distribution average (Hobday et al., 2018).